--[[

Author: Faerosong of Winterhoof

Sapped!

This addon provides battlefield intelligence both for you and your team.  It alerts when you are sapped
so they can prepare to strike or to know where they need to provide support.

Inspired by
SaySapped by Bitbyte of Icecrown

Usage: go to Interface->Add-ons->Sapped!

Changelog

2012.05.09.001
First beta release

2012.05.07.001
Cleaned up code and fixed bugs related to boolean values

2012.05.04.003
Added code to stop trying to send text to non-existant channels

2012.05.04.002
Fixed bugs and optimized and also it works now.

2012.05.04.001
First Release

]]--

local Version = "2012.05.09.001"

SappedOptions = {};
SappedOptions.panel = CreateFrame( "Frame", "SappedPanel");
SappedOptions.panel.name = L_SAPPED;
InterfaceOptions_AddCategory(SappedOptions.panel);

local IntroMessageHeader = SappedOptions.panel:CreateFontString(nil, "ARTWORK","GameFontNormalLarge");
IntroMessageHeader:SetPoint("TOPLEFT", 10, -10);
IntroMessageHeader:SetText(L_SAPPED..Version);

local EnabledCheck = CreateFrame("CheckButton", "Sapped_EnableCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
EnabledCheck:SetPoint("TOPLEFT",10,-35)	
EnabledCheck.Text = EnabledCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
EnabledCheck.Text:SetPoint("LEFT", EnabledCheck, "RIGHT", 0)
EnabledCheck.Text:SetText(L_ENABLED)
EnabledCheck.tooltipText = L_ENABLETIP
EnabledCheck:SetScript("OnClick", function(self, button, down)
  EnabledBool = EnabledCheck:GetChecked()
  if EnabledBool == nil then
    EnabledBool = 0
  end
end)

local SayCheck = CreateFrame("CheckButton", "Sapped_SayCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
SayCheck:SetPoint("TOPLEFT",10,-65)	
SayCheck.Text = SayCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
SayCheck.Text:SetPoint("LEFT", SayCheck, "RIGHT", 0)
SayCheck.Text:SetText(L_SAY)
SayCheck.tooltipText = L_SAYTIP
SayCheck:SetScript("OnClick", function(self, button, down)
  SayBool = SayCheck:GetChecked()
  if SayBool == nil then
    SayBool = 0
  end
end)

local PartyCheck = CreateFrame("CheckButton", "Sapped_PartyCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
PartyCheck:SetPoint("TOPLEFT",10,-95)	
PartyCheck.Text = PartyCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
PartyCheck.Text:SetPoint("LEFT", PartyCheck, "RIGHT", 0)
PartyCheck.Text:SetText(L_PARTY)
PartyCheck.tooltipText = L_PARTYTIP
PartyCheck:SetScript("OnClick", function(self, button, down)
  PartyBool = PartyCheck:GetChecked()
  if PartyBool == nil then
    PartyBool = 0
  end
end)

local BattlegroundCheck = CreateFrame("CheckButton", "Sapped_BattlegroundCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
BattlegroundCheck:SetPoint("TOPLEFT",10,-125)	
BattlegroundCheck.Text = BattlegroundCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
BattlegroundCheck.Text:SetPoint("LEFT", BattlegroundCheck, "RIGHT", 0)
BattlegroundCheck.Text:SetText(L_BATTLEGROUND)
BattlegroundCheck.tooltipText = L_BATTLEGROUNDTIP
BattlegroundCheck:SetScript("OnClick", function(self, button, down)
  BattlegroundBool = BattlegroundCheck:GetChecked()
  if BattlegroundBool == nil then
    BattlegroundBool = 0
  end
end)

local RAIDCheck = CreateFrame("CheckButton", "Sapped_RAIDCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
RAIDCheck:SetPoint("TOPLEFT",10,-155)	
RAIDCheck.Text = RAIDCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
RAIDCheck.Text:SetPoint("LEFT", RAIDCheck, "RIGHT", 0)
RAIDCheck.Text:SetText(L_RAID)
RAIDCheck.tooltipText = L_RAIDTIP
RAIDCheck:SetScript("OnClick", function(self, button, down)
  RAIDBool = RAIDCheck:GetChecked()
  if RAIDBool == nil then
    RAIDBool = 0
  end
end)

local Sapped = CreateFrame("Frame")
Sapped.playername = UnitName("player")
Sapped:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
Sapped:RegisterEvent("ADDON_LOADED");

Sapped:SetScript("OnEvent", function(...)

            if (select(2,...) == "ADDON_LOADED") then
              if (EnabledBool == nil) then
                  EnabledBool = 1
                end
              EnabledCheck:SetChecked(EnabledBool)
	
              if (SayBool == nil) then
                  SayBool = 1
                end
              SayCheck:SetChecked(SayBool)

              if (PartyBool == nil) then
                  PartyBool = 0
                end
              PartyCheck:SetChecked(PartyBool)

              if (BattlegroundBool == nil) then
                  BattlegroundBool = 1
                end
              BattlegroundCheck:SetChecked(BattlegroundBool)

              if (RAIDBool == nil) then
                  RAIDBool = 0
                end
              RAIDCheck:SetChecked(RAIDBool)
            end

            if ((EnabledBool == 1) and (select(14,...) == 6770)
	and (select(11,...) == Sapped.playername)
	and (select(4,...) == "SPELL_AURA_APPLIED" or select(4,...) == "SPELL_AURA_REFRESH"))
	then
                local subzone = GetSubZoneText()

                if (SayBool == 1) then
                  SendChatMessage(L_SAPPED, "SAY")
                end
  
                if (PartyBool == 1) and (subzone ~= "") and (GetNumPartyMembers() > 0) then
                  SendChatMessage(L_SAPPEDAT .. subzone .. L_BY .. select(7,...), "PARTY")
                end

                if (BattlegroundBool == 1) and (subzone ~= "") and (GetBattlefieldInstanceRunTime() > 0) then
                  SendChatMessage(L_SAPPEDAT .. subzone .. L_BY .. select(7,...), "BATTLEGROUND")
                end

                if (RAIDBool == 1) and (subzone ~= "") and UnitInRaid("player") then
                  SendChatMessage(L_SAPPEDAT .. subzone .. L_BY .. select(7,...), "RAID")
                end  
                                 
                DEFAULT_CHAT_FRAME:AddMessage(L_SAPPEDBY .. (select(7,...) or L_UNKNOWN))
	end
end)

DEFAULT_CHAT_FRAME:AddMessage(L_SAPPED .. Version .. L_LOADED)
